@@ -1,6 +1,5 @@
 import json
 import os.path
-from socket import timeout
 from typing import Dict, Any, Optional, List
 
 from requests_toolbelt import MultipartEncoder
@@ -41,7 +40,13 @@ class X_API:
             dataset_id: str
     ) -> Dict[str, Any]:
         response = self._client.open_api_do("GET", "", dataset_id).json()
-        return response["data"][0]
+
+        try:
+            info = response["data"][0]
+        except IndexError as error:
+            raise ResourceNotExistError(resource="dataset", identification=dataset_id) from error
+
+        return info
 
     def get_dataset(
             self,
@@ -290,6 +295,13 @@ class X_API:
     ) -> None:
         self._client.open_api_do("POST", "export", dataset_id, json=post_data)
 
+    def post_export_multi(
+            self,
+            dataset_id: str,
+            post_data: str
+    ) -> None:
+        self._client.open_api_do("POST", "export/multi", dataset_id, json=post_data)
+
     def get_export_status(
             self,
             dataset_id: str
