@@ -250,6 +250,49 @@ class Dataset(DatasetMeta):
 
         return self.iter_current_object[index - self.iter_current_start]
 
+    def import_data_with(
+            self,
+            task_type: str,
+            payloads: List[str],
+            transcode: Optional[bool] = False
+    ) -> None:
+        """Upload and import data to dataset with existed data(id,http_url,s3...).
+
+        Arguments:
+            type: Local file path, can be either file or directory.
+            task_type: Import task type, includes
+              1. "object_id": 数据Id导入, payloads是 id的列表
+              2. "http_files": http文件导入, payloads是 可访问的http url的列表
+            transcode: Whether converse format of data, only used for video.
+
+        """
+        if not task_type:
+            raise InvalidParamsError(param_name="task_type", param_value=task_type)
+
+        if task_type not in {"object_id", "http_files"}:
+            raise InvalidParamsError(param_name="task_type", param_value=task_type)
+
+        if len(payloads) <= 0:
+            raise InvalidParamsError(param_name="payloads", param_value=payloads)
+        
+        post_data: Dict[str, Any] = {
+            "transcode": transcode,
+            "create_timestamp": int(time.time() * 1000),
+            "data_type": self._data_type,
+            "data_url": payloads,
+            "import_type": "none",
+            "task_type": task_type
+        }
+
+        self._x_api.post_import(self._id, post_data)
+
+        print(f"import data to dataset start, please wait...")
+
+        with tqdm(total=100) as pbar:
+            self._validate_import(pbar)
+
+        self.checkout(self._version)
+
     def import_data(
             self,
             file_path: str,
