@@ -3,16 +3,15 @@ import time
 from metaloop.client import MDS
 
 if __name__ == '__main__':
-    mds_client = MDS("0c02ca70e142b75a75ca4118ce33dbb0", "http://192.168.100.71:30301")
+    mds_client = MDS("0c03ca70e142b75a75ca4118ce33ddd0")
 
-    date_time = time.strftime("%Y%m%d%H%M%S", time.localtime())
-    dataset_name = f"test_dataset_{date_time}"
+    dataset_name = f"test_dataset_for_sdk"
 
     # create dataset
     dataset = mds_client.create_dataset(
         dataset_name,
         "image",
-        ["screw"],
+        ["test"],
         comment="this is a test dataset for mds"
     )
 
@@ -28,6 +27,14 @@ if __name__ == '__main__':
     dataset.import_data("import_test/sample_test", storage_type="cos")
     dataset.summary()
 
+    # import with object ids
+    object_ids = []
+    for item in dataset:
+        print(item)
+        object_ids.append(item['id'])
+    dataset.import_data_with('object_id', object_ids)
+    dataset.summary()
+
     # create a new version and inherit data from a previous version
     dataset.create_version(0, "this is a inherited test version")
     dataset.summary()
